[Scummvm-cvs-logs] SF.net SVN: scummvm: [28436] scummvm/trunk/engines/agi/graphics.cpp

buddha_ at users.sourceforge.net buddha_ at users.sourceforge.net
Fri Aug 3 20:20:59 CEST 2007


Revision: 28436
          http://scummvm.svn.sourceforge.net/scummvm/?rev=28436&view=rev
Author:   buddha_
Date:     2007-08-03 11:20:58 -0700 (Fri, 03 Aug 2007)

Log Message:
-----------
Added Apple IIGS arrow cursor data.

Modified Paths:
--------------
    scummvm/trunk/engines/agi/graphics.cpp

Modified: scummvm/trunk/engines/agi/graphics.cpp
===================================================================
--- scummvm/trunk/engines/agi/graphics.cpp	2007-08-03 17:51:36 UTC (rev 28435)
+++ scummvm/trunk/engines/agi/graphics.cpp	2007-08-03 18:20:58 UTC (rev 28436)
@@ -911,8 +911,28 @@
 };
 
 /**
  * RGBA-palette for the black and white SCI-style arrow cursor.
  */
+static const byte appleIIgsMouseCursor[] = {
+	2,2,0,0,0,0,0,0,0,
+	2,1,2,0,0,0,0,0,0,
+	2,1,1,2,0,0,0,0,0,
+	2,1,1,1,2,0,0,0,0,
+	2,1,1,1,1,2,0,0,0,
+	2,1,1,1,1,1,2,0,0,
+	2,1,1,1,1,1,1,2,0,
+	2,1,1,1,1,1,1,1,2,
+	2,1,1,2,1,1,2,2,0,
+	2,2,2,0,2,1,1,2,0,
+	0,0,0,0,0,2,2,2,0
+};
+
+/**
+ * RGBA-palette for the black and white SCI and Apple IIGS arrow cursors.
+ */
 static const byte sciMouseCursorPalette[] = {
 	0x00, 0x00, 0x00,	0x00, // Black
 	0xFF, 0xFF, 0xFF,	0x00  // White
@@ -911,8 +911,28 @@
 
 /**
- * RGBA-palette for the black and white SCI-style arrow cursor.
+ * A black and white Apple IIGS style arrow cursor (9x11).
+ * 0 = Transparent.
+ * 1 = Black (#000000 in 24-bit RGB).
+ * 2 = White (#FFFFFF in 24-bit RGB).
  */


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list